@@ -6,7 +6,7 @@ test_that("throws error", {
   expect_error(prec_sens(.5, prev = 1.1, ntot = 100, method = "wilson"))
   expect_error(prec_sens(.5, ntot = 100, method = "wilson"))
   expect_error(prec_sens(.5, prev = 100, method = "wilson"))
-  expect_error(prec_sens(.5, prev = .1, method = "wilson", conf.width = .1))
+  expect_error(prec_sens(.5, prev = .1, method = "wilson", conf.width = .1), NA)
   expect_message(prec_sens(.5, prev = .1, ntot = 100, method = "wilson"))
   expect_error(prec_sens(.5, n = 100, ntot = 100, prev = .6, method = "wilson"))
   expect_error(prec_spec(1.1, 100, method = "wilson"))
@@ -14,7 +14,7 @@ test_that("throws error", {
   expect_error(prec_spec(.5, prev = 1.1, ntot = 100, method = "wilson"))
   expect_error(prec_spec(.5, ntot = 100, method = "wilson"))
   expect_error(prec_spec(.5, prev = 100, method = "wilson"))
-  expect_error(prec_spec(.5, prev = .1, method = "wilson", conf.width = .1))
+  expect_error(prec_spec(.5, prev = .1, method = "wilson", conf.width = .1), NA)
   expect_message(prec_spec(.5, prev = .1, ntot = 100, method = "wilson"))
   expect_error(prec_spec(.5, n = 100, ntot = 100, prev = .6, method = "wilson"))
 })
